@@ -111,3 +111,29 @@ def string_to_metatype(string):
         raise TypeError('string must be a str')
 
     return Metatype[string.upper()]
+
+class PredictionMethod(IntEnum):
+    """Prediction method of predictor."""
+    PREDICT = 0
+    PREDICT_PROBA = 1
+    DECISION_FUNCTION = 2
+
+def is_prediction_method(prediction_method, strict = False):
+    """Checks if prediction_method is valid.
+
+    Args:
+        prediction_method: PredictionMethod or int.
+        strict: checks if prediction_method is PredictionMethod.
+
+    Returns:
+        bool.
+    """
+    if strict and not isinstance(prediction_method, PredictionMethod):
+        return False
+
+    try:
+        PredictionMethod(prediction_method)
+    except ValueError:
+        return False
+
+    return True
